config

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 11, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	BaseURL string `mapstructure:"base_url"`
	PSK     string `mapstructure:"psk"`
}

func New

func New() *Config

func (*Config) AddFlags

func (c *Config) AddFlags(cmd *cobra.Command)

AddFlags adds flags to a Cobra command and binds them to Viper

func (*Config) Load

func (c *Config) Load() error

Load initializes Viper, loads the configuration, and populates the Config struct

Jump to