package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Jan 11, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
BaseURL string `mapstructure:"base_url"`
PSK string `mapstructure:"psk"`
}
AddFlags adds flags to a Cobra command and binds them to Viper
Load initializes Viper, loads the configuration, and populates the Config struct
Source Files
¶
Click to show internal directories.
Click to hide internal directories.